@@ -19,7 +19,7 @@ module Jekyll
       end
 
       def build_toc
-        %(<ul class="#{@configuration.list_class}">\n#{build_toc_list(@entries)}</ul>)
+        %(<#{list_tag} id="#{@configuration.list_id}" class="#{@configuration.list_class}">\n#{build_toc_list(@entries)}</#{list_tag}>)
       end
 
       def inject_anchors_into_html
@@ -74,7 +74,7 @@ module Jekyll
             next_i = i + 1
             if next_i < entries.count && entries[next_i][:h_num] > min_h_num
               nest_entries = get_nest_entries(entries[next_i, entries.count], min_h_num)
-              toc_list << %(\n<ul#{ul_attributes}>\n#{build_toc_list(nest_entries)}</ul>\n)
+              toc_list << %(\n<#{list_tag}#{ul_attributes}>\n#{build_toc_list(nest_entries)}</#{list_tag}>\n)
               i += nest_entries.count
             end
             # Add the closing tag for the current entry in the list
@@ -107,7 +107,7 @@ module Jekyll
       end
 
       def toc_headings_in_no_toc_section
-        if @configuration.no_toc_section_class.is_a? Array
+        if @configuration.no_toc_section_class.is_a?(Array)
           @configuration.no_toc_section_class.map { |cls| toc_headings_within(cls) }.join(',')
         else
           toc_headings_within(@configuration.no_toc_section_class)
@@ -121,6 +121,10 @@ module Jekyll
       def ul_attributes
         @ul_attributes ||= @configuration.sublist_class.empty? ? '' : %( class="#{@configuration.sublist_class}")
       end
+
+      def list_tag
+        @list_tag ||= @configuration.ordered_list ? 'ol' : 'ul'
+      end
     end
   end
 end
